/* -*-objc-*- 
   NSArray+GSDoc.h <title></title>

   Copyright (C) 2000-2002,2004,2005 Free Software Foundation, Inc.

   Author: Manuel Guesdon <mguesdon@orange-concept.com>
   Date: August 2000

   $Revision: 21645 $
   $Date: 2005-08-17 10:07:57 +0200 (Mit, 17 Aug 2005) $

   <abstract></abstract>

   This file is part of the GNUstep Database Library.

   <license>
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
   </license>
**/

// $Id: NSArray+GSDoc.h 21645 2005-08-17 08:07:57Z ayers $

#ifndef __NSArray_GSDoc_h__
#define __NSArray_GSDoc_h__

#include <Foundation/NSArray.h>


@interface NSArray (GSDoc)

- (NSString *)gsdocContentWithIdPtr: (int *)xmlIdPtr;
- (NSString *)gsdocContentWithTagName: (NSString *)tagName
				idPtr: (int *)xmlIdPtr;
- (NSString *)gsdocContentWithTagName: (NSString *)tagName
                    elementsTagName: (NSString *)elementsTagName
				idPtr: (int *)xmlIdPtr;

@end


#endif /* __NSArray_GSDoc_h__ */
